#' @title reading some fit indicees from Mplus output
#' @export Mplus_fit
# @docType function
#' @description This function reads the fit-indicees "ChiSq","df","p","CFI","RMSEA","SRMR" and returns them as a list and writes them (optinaly) as a csv file into the current workspace directory.
#' @details no details   
#' @param target name of the Mplus output file - e.g. target = "MyMplus.out" 
#' @param w logical - write fit coefficiants as csv table? - default: \code{w = FALSE}.
#' @param ... additional parameters passed through
#' @return a list and a .csv file in current workspace directory.
#' @examples 
#' ## first preparing an Mplus output data
#' data(example2) # loading fictional example correlation matrix
#' Mplus_esyn(N = 300, Kor = example2)
#' ## !!! now first open the data example1.inp in Mplus and click run !!! 
#' ##### not run until Mplus is installed on your system #####
#' # Mplus_fit("example2.out")
################# funktionsbegin #########
Mplus_fit<-function (target,w=FALSE,...)
{
  # library(MplusAutomation)
  temp<-extractModelSummaries(target = target,...)
  koef<-c( temp$ Filename,temp$ ChiSqM_Value, temp$ ChiSqM_DF, temp$ ChiSqM_PValue,temp$ CFI, temp$ RMSEA_Estimate, temp$ SRMR)
  nam<-c( "Datei","ChiSq","df","p","CFI","RMSEA","SRMR")  
  Dateiname<-gsub(".out","",temp$ Filename)
  
  if (w==TRUE) {write.table((rbind(nam,koef)), file = paste("FIT", Dateiname, ".csv",sep=""), row.names = F, col.names = F, sep = ";")}
erg<-list(Mplus_file = temp$ Filename, fit = list(Chi = temp$ ChiSqM_Value, df = temp$ ChiSqM_DF, p = temp$ ChiSqM_PValue, CFI = temp$ CFI, RMSEA =temp$ RMSEA_Estimate, SRMR = temp$ SRMR ))
  return(erg)
  } # ende der funktion