\name{Circ_emp}
\alias{Circ_emp}
\title{Running Mplus for empirical RIASEC angular locations}
\usage{
  Circ_emp(N, Kor,
    konstrukt = c("R", "I", "A", "S", "E", "C"),
    showOutput = TRUE,
    Mplus_command = "/Applications/Mplus 7/mplus",
    replaceOutfile = "always", name = "", ...)
}
\arguments{
  \item{N}{number of observations for correlations as
  numeric}

  \item{Kor}{either an R matrix object with RIASEC
  correlations or the name of a correlation matrix, stored
  as a .dat text file, as character. If parameter
  \code{Kor} is a matrix then correlation will be saved as
  .dat file in current workspace directory.}

  \item{konstrukt}{optionaly a character vector with length
  = 6 containing labels for construct dimensions - default
  is konstrukt = c("R","I","A","S","E","C").}

  \item{showOutput}{default set to \code{TRUE} - see
  description of the function \code{runModels()} in package
  \code{\link[MplusAutomation]{MplusAutomation}}.}

  \item{Mplus_command}{default set to
  \code{"/Applications/Mplus\ 7/mplus"} for MAC OS X
  systems having Mplus version 7 installed in an sub
  directory namend "Mplus 7" in Applications folder.
  Windows users having Mplus installed with the standard
  settings should change the argument to
  \code{Mplus_command="mplus"} - see examples and see
  description of the function \code{runModels()} in package
  \code{\link[MplusAutomation]{MplusAutomation}}.}

  \item{replaceOutfile}{default set to "always" - see
  description of the function \code{runModels()} in package
  \code{\link[MplusAutomation]{MplusAutomation}}.}

  \item{name}{optional a name (as character) for the Mplus
  syntax to be saved - default is the object name or the
  name given in paramter \code{Kor} as character (with
  ending changed to '.inp').}

  \item{...}{additional parameters passed through}
}
\value{
  returns a list object of class Circ_emp. Generated Mplus
  syntax wil be saved in the current working directory and
  used for estimation. If parameter \code{Kor} is a matrix
  then correlation will be saved as . dat file in current
  workspace directory too.
}
\description{
  This function generates and runs Mplus syntax which is
  discussed in Nagy et. al. (2009) and extracts the
  estimated model parameters - the angular locations of the
  six RIASEC dimensions, based on their correlations, in
  the asumed circumplex array within the theory of
  vocational choice by John Holland (1997).
}
\details{
  more to come ...
}
\examples{
## generating runing and extracting parameters from Mplus files refering to a correlation data stored in the already existing text file example2.dat
data(example2) # loading fictional example correlation matrix
# not Run until Mplus is installed on your Sytem #####
#----------choose your system !---------------------------------------
# MAC user:       test <- Circ_emp(300,example2)
# Windows user:   test <- Circ_emp(300,example2,Mplus_command="mplus")
#---------------------------------------------------------------------
# test
### ploting the result as a circumplex
# plot(test)
}
\references{
  Holland, J.L. (1997). \emph{Making vocational choices. A
  theory of vocational personalities and work
  environments}. Lutz, FL: Psychological Assessment
  Resources.

  Nagy, G., Marsh, H. W., Luedtke, O., & Trautwein, U.
  (2009). Representing circles in our minds: Confirmatory
  factor analysis of circumplex structures and profiles. In
  T. Teo & M. S. Khine (Hrsg.), \emph{Structural Equation
  Modeling in Educational Research: Concepts and
  applications} (S. 287 - 315). Rotterdam Boston Taipei:
  Sense Publishers.
}

